package com.ruoyi.system.mapper;


import com.ruoyi.system.domain.assessment.ZxAssessment;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 政协评价考核Mapper接口
 * 
 * @author boman
 * @date 2024-03-19
 */
public interface ZxAssessmentMapper 
{
    /**
     * 查询政协评价考核
     * 
     * @param assessmentId 政协评价考核主键
     * @return 政协评价考核
     */
    public ZxAssessment selectZxAssessmentByAssessmentId(Long assessmentId);

    /**
     * 查询政协评价考核列表
     * 
     * @param zxAssessment 政协评价考核
     * @return 政协评价考核集合
     */
    public List<ZxAssessment> selectZxAssessmentList(ZxAssessment zxAssessment);

    /**
     * 新增政协评价考核
     * 
     * @param zxAssessment 政协评价考核
     * @return 结果
     */
    public int insertZxAssessment(ZxAssessment zxAssessment);
    public ZxAssessment checkAssessmentProjectUnique(@Param("AssessmentTypeId") String assessmentTypeId, @Param("parentId") Long parentId);

    /**
     * 修改政协评价考核
     * 
     * @param zxAssessment 政协评价考核
     * @return 结果
     */
    public int updateZxAssessment(ZxAssessment zxAssessment);

    /**
     * 删除政协评价考核
     * 
     * @param assessmentId 政协评价考核主键
     * @return 结果
     */
    public int deleteZxAssessmentByAssessmentId(Long assessmentId);

    /**
     * 批量删除政协评价考核
     * 
     * @param assessmentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZxAssessmentByAssessmentIds(Long[] assessmentIds);
}
